@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from asyncio import Lock
 from collections.abc import Callable
 from dataclasses import dataclass, field
 from typing import Any, Generic, TypeAlias, TypeVar, overload
@@ -154,6 +155,7 @@ class ListDataManager(DataManager[list[T]]):
         self.deserializer = deserializer
 
     async def append(self, value: T) -> None:
-        sequence = await self.get(default=[])
-        sequence.append(value)
-        await self.set(sequence)
+        async with Lock():
+            sequence = await self.get(default=[])
+            sequence.append(value)
+            await self.set(sequence)
