@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from functools import cache
 from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 from aiogram.fsm.state import State
@@ -13,6 +14,8 @@ if TYPE_CHECKING:
 
 StateT = TypeVar("StateT", bound=State)
 
+INITED_STATES: list[ExtendedState[Any, Any]] = []
+
 
 @dataclass(slots=True, frozen=True)
 class ExtendedStateManager(FSMContextMixin):
@@ -36,5 +39,24 @@ class ExtendedStateManager(FSMContextMixin):
             msg = f"`{current_state}` is the last state."
             raise ValueError(msg) from e
 
+    @staticmethod
+    @cache
+    def get_state_by_id(state_id: str) -> ExtendedState[Any, Any] | None:
+        for state in INITED_STATES:
+            if state.state == state_id:
+                return state
+
+        return None
+
+    async def get_current_state(self) -> ExtendedState[Any, Any] | None:
+        state_id = await self.fsm.get_state()
+        if state_id is None:
+            return None
+
+        return self.get_state_by_id(state_id)
+
+    async def is_active(self, state: State) -> bool:
+        return await self.fsm.get_state() == state.state
+
 
 EXTENDED_STATE_MANAGER = ExtendedStateManager()
