@@ -9,12 +9,13 @@ from typing_extensions import TypeVar
 from better_fsm.data.manager import DataManager
 from better_fsm.states.manager import (
     EXTENDED_STATE_MANAGER,
+    INITED_STATES,
     ExtendedStateManager,
 )
 from better_fsm.utils.attrs import lazy_attribute
 
 if TYPE_CHECKING:
-    from collections.abc import Callable
+    from collections.abc import Awaitable, Callable
 
 
 DataTypeT = TypeVar("DataTypeT", bound=Any, default=Any)
@@ -34,6 +35,8 @@ class ExtendedState(State, Generic[DataTypeT, NextStateT]):
         manager: ExtendedStateManager = EXTENDED_STATE_MANAGER,
         state: str | None = None,
         group_name: str | None = None,
+        on_enter: Callable[[], Awaitable[None]] | None = None,
+        on_exit: Callable[[], Awaitable[None]] | None = None,
     ) -> None:
         super().__init__(
             state=state,
@@ -53,8 +56,21 @@ class ExtendedState(State, Generic[DataTypeT, NextStateT]):
         else:
             self._next_state_factory = next_state
 
+        async def _do_nothing() -> None:
+            pass
+
+        self.on_enter = on_enter or _do_nothing
+        self.on_exit = on_exit or _do_nothing
+
+        INITED_STATES.append(self)
+
     async def set(self) -> Self:
         """Set current state equal to this state."""
+        current_state = await self.get_current()
+        if current_state is not None:
+            await current_state.on_exit()
+
+        await self.on_enter()
         return await self.manager.set(self)
 
     @lazy_attribute
@@ -90,6 +106,13 @@ class ExtendedState(State, Generic[DataTypeT, NextStateT]):
 
         return next_state
 
+    async def is_active(self) -> bool:
+        """Check if current state is equal to this state."""
+        return await self.manager.is_active(self)
+
+    async def get_current(self) -> ExtendedState[Any, Any] | None:
+        return await self.manager.get_current_state()
+
     if not TYPE_CHECKING:
 
         def __class_getitem__(
